.. ks33requests documentation master file, created by
   sphinx-quickstart on Mon Jun 24 18:04:37 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

ks33requests Documentations
###########################


:Release: |release|
:Date:    |today|
:Version: |version|

------

Docs
----

.. toctree::
   :glob:
   :maxdepth: 1

   README <README>
   CHANGELOG
   CONTRIBUTING
   AUTHORS

Examples
--------

.. toctree::
   :glob:
   :maxdepth: 1

   notebooks/*

API
---

.. toctree::
   :glob:
   :maxdepth: 4

   api/modules


Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
